# `royalherald` [![PyPI](https://img.shields.io/pypi/v/royalherald.svg)](https://pypi.org/project/royalherald/)


A websocket communication protocol for [`royalnet`](https://github.com/Steffo99/royalnet)!
